@@ -574,6 +574,15 @@ class MongoEngineResource(resources.ModelResource):
 
         return result
 
+    @classmethod
+    def api_field_options(cls, name, field, options):
+        """
+        Allows dynamic change of field options when creating resource
+        fields from document fields automatically.
+        """
+
+        return options
+
     @classmethod
     def get_fields(cls, fields=None, excludes=None):
         """
@@ -631,6 +640,8 @@ class MongoEngineResource(resources.ModelResource):
                     if f.default is not None: # If not MongoEngine's default
                         kwargs['default'] = f.default
 
+            kwargs = cls.api_field_options(name, f, kwargs)
+
             final_fields[name] = api_field_class(**kwargs)
             final_fields[name].instance_name = name
 
