@@ -120,6 +120,7 @@ class BasicTest(test_runner.MongoEngineTestCase):
         self.assertEqual(response['person']['name'], 'Person 1 UPDATED')
         self.assertEqual(response['person']['optional'], None)
         self.assertEqual(response['person']['resource_uri'], self.fullURItoAbsoluteURI(person1_uri))
+        self.assertEqual(response['employed'], False)
 
         response = self.c.post(self.resourceListURI('customer'), '{"person": "%s"}' % self.fullURItoAbsoluteURI(person1_uri), content_type='application/json')
         self.assertEqual(response.status_code, 201)
@@ -363,10 +364,21 @@ class BasicTest(test_runner.MongoEngineTestCase):
         response = self.c.get(customer2_uri)
         self.assertEqual(response.status_code, 200)
         response = json.loads(response.content)
-
+        
         self.assertEqual(response['person']['name'], 'Person 1 PATCHED')
         self.assertEqual(response['person']['optional'], 'Optional PATCHED')
 
+        self.assertEqual(response['employed'], False)
+
+        response = self.c.patch(customer2_uri, '{"employed": true}', content_type='application/json')
+        self.assertEqual(response.status_code, 202)
+
+        response = self.c.get(customer2_uri)
+        self.assertEqual(response.status_code, 200)
+        response = json.loads(response.content)
+
+        self.assertEqual(response['employed'], True)
+
         response = self.c.patch(embeddeddocumentfieldtest_uri, '{"customer": {"name": "Embedded person PATCHED"}}', content_type='application/json')
         self.assertEqual(response.status_code, 202)
 
@@ -434,7 +446,7 @@ class BasicTest(test_runner.MongoEngineTestCase):
         self.assertEqual(response.status_code, 200)
         response = json.loads(response.content)
 
-        self.assertEqual(len(response['fields']), 3)
+        self.assertEqual(len(response['fields']), 4)
         self.assertEqual(response['fields']['person']['reference_uri'], self.resourceListURI('person'))
 
         listfieldtest_schema_uri = self.resourceListURI('listfieldtest') + 'schema/'
